import pandas as pd
import numpy as np
from datetime import datetime, timedelta
from feast import FeatureStore

# Parameters
num_entries = 5  # Number of rows in entity_df
customer_ids = [1, 2, 3, 4, 5]  # Specific customer IDs to include

# Timestamp range for randomization
start_timestamp = pd.Timestamp("2024-10-19 00:00:00", tz="UTC")
end_timestamp = pd.Timestamp("2024-10-20 23:59:59", tz="UTC")

# Generate customer_id and random timestamps within the range
customer_id_choices = np.random.choice(customer_ids, size=num_entries)
timestamps = [
    start_timestamp + timedelta(
        seconds=np.random.randint(0, int((end_timestamp - start_timestamp).total_seconds()))
    )
    for _ in range(num_entries)
]

# Create the DataFrame
entity_df = pd.DataFrame({
    "customer_id": customer_id_choices,
    "event_timestamp": pd.to_datetime(timestamps),
})

print("Generated entity_df:")
print(entity_df)


# # Initialize the feature store with the path to the feature repo
fs = FeatureStore(repo_path="feature_repo/")

# Retrieve historical features for these customers at the specified timestamps
training_df = fs.get_historical_features(
    features=[
        "customer_purchases:purchase_amount",
        "customer_purchases:purchase_category"
    ],
    entity_df=entity_df
).to_df()

# Display the retrieved historical features DataFrame
print("Historical features DataFrame:")
print(training_df)